@@ -68,7 +68,8 @@ BEGIN {
 		      reflog_cache_insert reflog_cache_lookup
                       $package_re $component_re $suite_re $deliberately_re
 		      $distro_re $versiontag_re $series_filename_re
-		      $orig_f_comp_re $orig_f_sig_re $orig_f_tail_re
+		      $orig_f_comp_re $orig_f_sig_re
+		      $tarball_f_ext_re $orig_f_tail_re
 		      $extra_orig_namepart_re
 		      $git_null_obj
                       $branchprefix
@@ -83,7 +84,7 @@ BEGIN {
 		      gdr_ffq_prev_branchinfo
 		      parsecontrolfh parsecontrol parsechangelog
 		      getfield parsechangelog_loop
-		      playtree_setup);
+		      playtree_setup playtree_write_gbp_conf);
     # implicitly uses $main::us
     %EXPORT_TAGS = ( policyflags => [qw(NOFFCHECK FRESHREPO NOCOMMITCHECK)],
 		     playground => [qw(record_maindir $maindir $local_git_cfg
@@ -107,7 +108,8 @@ our $series_filename_re = qr{(?:^|\.)series(?!\n)$}s;
 our $extra_orig_namepart_re = qr{[-0-9a-zA-Z]+};
 our $orig_f_comp_re = qr{orig(?:-$extra_orig_namepart_re)?};
 our $orig_f_sig_re = '\\.(?:asc|gpg|pgp)';
-our $orig_f_tail_re = "$orig_f_comp_re\\.tar(?:\\.\\w+)?(?:$orig_f_sig_re)?";
+our $tarball_f_ext_re = "\\.tar(?:\\.\\w+)?(?:$orig_f_sig_re)?";
+our $orig_f_tail_re = "$orig_f_comp_re$tarball_f_ext_re";
 our $git_null_obj = '0' x 40;
 our $ffq_refprefix = 'ffq-prev';
 our $gdrlast_refprefix = 'debrebase-last';
@@ -632,12 +634,15 @@ sub git_check_unmodified () {
 sub upstream_commitish_search ($$) {
     my ($upstream_version, $tried) = @_;
     # todo: at some point maybe use git-deborig to do this
+    my @found;
     foreach my $tagpfx ('', 'v', 'upstream/') {
 	my $tag = $tagpfx.(dep14_version_mangle $upstream_version);
 	my $new_upstream = git_get_ref "refs/tags/$tag";
 	push @$tried, $tag;
-	return $new_upstream if length $new_upstream;
+	push @found, [ $tag, $new_upstream ] if $new_upstream;
     }
+    return @{ $found[0] } if @found == 1;
+    return ();
 }
 
 sub resolve_upstream_version ($$) {
@@ -647,7 +652,8 @@ sub resolve_upstream_version ($$) {
     my $message = __ 'using specified upstream commitish';
     if (!defined $new_upstream) {
 	my @tried;
-	$new_upstream = upstream_commitish_search $upstream_version, \@tried;
+	($used, $new_upstream) =
+	    upstream_commitish_search $upstream_version, \@tried;
 	if (!length $new_upstream) {
 	    fail f_
 		"Could not determine appropriate upstream commitish.\n".
@@ -655,7 +661,6 @@ sub resolve_upstream_version ($$) {
 		" Check version, and specify upstream commitish explicitly.",
 		"@tried";
 	}
-	$used = $tried[-1];
 	$message = f_ 'using upstream from git tag %s', $used;
     } elsif ($new_upstream =~ m{^refs/tags/($versiontag_re)$}s) {
 	$message = f_ 'using upstream from git tag %s', $1;
@@ -1072,6 +1077,20 @@ sub playtree_setup () {
     open GA, "> .git/info/attributes" or confess "$!";
     print GA "* $negate_harmful_gitattrs\n" or confess "$!";
     close GA or confess "$!";
+
+    playtree_write_gbp_conf();
+}
+
+sub playtree_write_gbp_conf (;$) {
+    my ($ignore_new) = @_;
+    $ignore_new //= 'false';
+    
+    open GC, "> .git/gbp.conf" or confess "$!";
+    print GC <<"END" or confess $!;
+[pq]
+ignore-new = $ignore_new
+END
+    close GC or confess "$!";
 }
 
 1;
